# repos

This folder stores cloned reference repositories.

`scix install-repos` and `scix up` clone missing repos here.

The contents of this folder are ignored by Git except for this README and
`.gitkeep`.
